#[repr(u8)]pub enum StateTransition {
L4FirstPacket = 0,
L4EndHshk = 1,
InL4Conn = 2,
InL4Stream = 3,
L7OnDisc = 4,
L7EndHdrs = 5,
L4Terminated = 6,
Packet = 7,
}Expand description
The possible state transitions that a data type, filter, or callback (function and/or struct) can be associated with. Developers should refer to these in macros.
Variants
L4FirstPacket = 0
On first packet in connection
L4EndHshk = 1
Observed and reassembled SYNs and ACKs from both sides. Note that this does not validate sequence numbers of these SYNs/ACKs. Additionally, this should not be used to indicate the beginning of payload, as payload may overlap with the handshake.
InL4Conn = 2
Streaming anywhere in L4 connection, including TCP handshake. Streaming anywhere in TCP or UDP connection, including TCP handshake.
InL4Stream = 3
Streaming anywhere in TCP or UDP connection, including TCP handshake. Packets are TCP-reassembled.
L7OnDisc = 4
On L7 protocol identification
L7EndHdrs = 5
On L6/L7 headers parsed
L4Terminated = 6
L4 connection terminated by FIN/ACK sequence or timeout
Packet = 7
Packet-level datatype. Any datatype tagged with this is built from a single, connectionless packet (Mbuf).
Note: Iris currently does not support subscriptions that are not tied to
a connection. Callbacks and filters should use InL4Conn to request
packet-level data types.
Packet-level filters cannot be combined with datatypes or callbacks that require connection/session tracking. Packet-level datatypes can only be requested in higher-level filters/callbacks if a streaming level (e.g., InL4Conn) is specified.
Internal notes:
- This must be last in the enum variant list.
- In the connection tracker, this is used as a no-op state transition.